# README for dataport-schuposh-ulc-hooks

This package adds project-specific adaption for the requirement: A002: User-Lifecycle.
The main work is done by UCS@School specific hooks.

## Hooks
These Hooks require at least UCS@School 4.4v9 and need to be available on all systems (here: DC Master & Backups).

| name                                 | description                                                                                                                                                                                                                                                         | type        | priority                          |
|--------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------|-----------------------------------|
| `generate_username.py`               | Implements the Class `GenerateUserName` to generate a new username when firstname or lastname are changed. The scheme is read from the `user_import.json`                                                                                                               | User Pyhook | pre_modify: 1000                  |
| `generate_mail_alias.py`             | Implements the Class `GenerateMailAlias` to add `mailPrimaryAddress` to `mailAlternativeAddress` and current datetime to `mailAddressExpired` when firstname or lastname are changed.                                                                                                                                                                                                                                                                                    | User Pyhook | pre/post_modify: 990                   |
| `generate_email.py`                  | Implements the Class `GenerateEmail` to generate a new `mailPrimaryAddress` when firstname or lastname are changed. The scheme is read from the `user_import.json`                                                                                                                                                                                                                                                                                                                                                                             | User Pyhook | pre_modify: 980                               |
| `send_mail_on_user_changes.py`       | Implements the class `SendEmailUsernameChanged` checks the user data for modification. In case of change sends an email to the appropriate schools of the user.                                                                                                                                                                                                                                                                                                                                                                                   | User PyHook | pre/post_modify: 800                          |
| `deactivate_user_before_deletion.py` | Implements the class `DeactivateUsersBeforeDeletion` to move the user to `transfer_school` (limbo) on deletion action. Hook will move the user when one school is assigned only. Otherwise the hook will change and remove the primary school from user.          | User PyHook | pre_remove: 200                   |
| `purge_deactivated_users.py`         | Implements the Class `PurgeDeactivatedUsers` to set the `ucsschoolPurgeTimestamp` when a user gets deactivated. The period in days when a user should get purged can be set via the UCR variable `dataport/schuposh/ulc/purge_period` (default: 90 days).               | User PyHook | post_modify: 100                  |
| `remove_old_schooladmin_groups.py`   | Implements the class `RemoveOldSchoolAdminGroups` to remove leftover groups on school change for SchoolAdmins caused by Bug 54368                                                                                                                                       | User Pyhook | post_modify: 200                  |


## Tests
The folder `tests` includes unit tests which can be used with `pytest`.
The tests are **non-idempotent**, which means they alter the system by creating/deleting users.

### Prerequisities
* UCS4.4-8 with UCS@School 4.4v9
* `python-pytest` installed
* `python-pytest-catchlog` installed (necessary for some tests). Already included in more recent `pytest` versions.
* existing OU DEMOSCHOOL2, create it with `/usr/share/ucs-school-import/scripts/create_ou DEMOSCHOOL2`
* existing OU DeaktivierteKonten, create it with `/usr/share/ucs-school-import/scripts/create_ou DeaktivierteKonten`
* configured email domain in univention management console
* configured email domain in ucr variable `mail/hosteddomains`

## UCR variables

### dataport/schuposh/ulc/purge_period
Duration of days, after which a deactivated user should be deleted.

Default: 84 days

### dataport/schuposh/ulc/purge_mail_alias
Duration of days, after which a mail alias should be deleted.

Default: 180 days

### dataport/schuposh/ulc/purge_mail_alias/cron
Check interval when expired mail aliases are purged. Cron syntax.

Default: `50 4 * * *` (every day at 4:50)

## Scripts
The script `/usr/share/dataport-schuposh/scripts/ulc_purge-expired-mail-aliases` is invoked by a cronjob and deletes all mail aliases (field: `mailAlternativeAddress`) whose timestamp (field: `mailAddressExpired`) is older than the value in `dataport/schuposh/ulc/purge_mail_alias`.

It supports the options `--dry-run` and `--verbose` and writes logs to `/var/log/univention/ulc_purge-mail-aliases.log`.

## LDAP extensions
This package extends the LDAP with `schuposh-custom-attributes-ulc.schema`:
* `schuposhUlcMailAddressExpired` - attribute which stores a list of dates when a mail address was set as alias
* `schuposhUlcAttributes` - object class to hold the attribute

The attribute above also gets mapped to an UDM extended attribute named `mailAddressExpired`.

## Join script 51dataport-schuposh-ulc-hooks.inst
The join script `51dataport-schuposh-ulc-hooks.inst` sets `disableUDMWeb=0` for the UCS@School attributes `ucsschoolRecordUID` and `ucsschoolSourceUID`, so that they become visible in the UDM users/user module.

Furthermore, it registers the LDAP schema extension, ensures the mapping of the LDAP attributes to UDM objects and prepares the UCR variables (if not set).

It runs only on DC Master.

## References
* [UCS@School manual](https://docs.software-univention.de/ucsschool-handbuch.html#import:pyhooks)
