from ucsschool.lib.models.user import Student, Teacher, SchoolAdmin, User
from univention.admin.uldap import access, getAdminConnection
from univention.config_registry import ConfigRegistry
from config import school
import json
import pytest
import random
import shutil
import string
import os

ucr = ConfigRegistry()
ucr.load()


@pytest.fixture
def get_factory_config():
	"""Is needed to add source_uid to the configuration."""
	return {
		"classes": {
			"reader": "ucsschool.importer.reader.http_api_csv_reader.HttpApiCsvReader"
		},
		"verbose": True,
		"source_uid": "ulc-test"
	}


@pytest.fixture
def write_factory_config_file(get_factory_config):
	"""
	Save the new factory config in the appropriate file and save the old file.
	"""
	config_file = "/usr/share/ucs-school-import/configs/user_import_http-api.json"
	if os.path.isfile(config_file):
		shutil.copyfile(config_file, config_file + '.bak')
	with open(config_file, 'w') as fp:
		json.dump(get_factory_config, fp, indent=4)


@pytest.fixture
def random_name():
	"""To create unique user names."""
	def _wrapper():
		return ''.join(random.choice(string.ascii_lowercase + string.digits)
			for _ in range(5))
	return _wrapper


@pytest.fixture
def get_host():
	return ucr["ldap/master"]


@pytest.fixture
def get_port():
	return int(ucr.get("ldap/master/port", "7389"))


@pytest.fixture
def get_base():
	return ucr["ldap/base"]


@pytest.fixture
def get_binddn_admin(get_base):
	return "uid=Administrator,cn=users,{0}".format(get_base)


@pytest.fixture
def get_binddn_school_admin(get_base):
	return "uid=demo_admin,cn=lehrer,cn=users,ou={0},{1}".format(
		school, get_base)


@pytest.fixture
def get_bindpw():
	return "univention"


@pytest.fixture
def get_mail_domain():
	return ucr["mail/hosteddomains"].split(" ")[0]


@pytest.fixture
def ldap_access_admin(get_host, get_port, get_base, get_binddn_school_admin, get_bindpw):
	lo = getAdminConnection()[0]
	return lo


@pytest.fixture
def ldap_access_school_admin(get_host, get_port, get_base, get_binddn_school_admin, get_bindpw):
	return access(host=get_host, port=get_port, base=get_base,
		binddn=get_binddn_school_admin,
		bindpw=get_bindpw, start_tls=2)


@pytest.fixture
def user_obj(random_name):
	def _wrapper(school):
		return User(name=random_name(),
			firstname=random_name(),
			lastname=random_name(),
			school=school)
	return _wrapper


@pytest.fixture
def student_obj(random_name):
	def _wrapper(school):
		return Student(name=random_name(),
			firstname=random_name(),
			lastname=random_name(),
			school=school)
	return _wrapper


@pytest.fixture
def teacher_obj(random_name):
	def _wrapper(school):
		return Teacher(name=random_name(),
			firstname=random_name(),
			lastname=random_name(),
			school=school)
	return _wrapper


@pytest.fixture
def schooladmin_obj(random_name):
	def _wrapper(school):
		return SchoolAdmin(name=random_name(),
			firstname=random_name(),
			lastname=random_name(),
			school=school)
	return _wrapper


@pytest.fixture
def create_user():
	def _wrapper(lo, user_object):
		user_object.create(lo)
	return _wrapper


@pytest.fixture
def remove_user():
	def _wrapper(lo, user_object):
		user_object.remove(lo)
	return _wrapper


@pytest.fixture
def remove_user_from_school():
	def _wrapper(school, lo, user_object):
		user_object.remove_from_groups_of_school(school, lo)
	return _wrapper


@pytest.fixture
def modify_user():
	def _wrapper(lo, user_object):
		user_object.modify(lo)
	return _wrapper


@pytest.fixture
def get_missing_groups():
	def _wrapper(expected_groups, groups):
		groups = [g.lower() for g in groups]
		return [
			exp_group
			for exp_group in expected_groups
			if not any([g.endswith(exp_group.lower()) for g in groups])
		]
	return _wrapper
