import logging
from config import school, school_group

logging.basicConfig(level=logging.DEBUG, format="%(message)s",
	handlers=[logging.StreamHandler()])

#
# Attention: This testcases will create users on the target system.
# Run this tests on a testing ucsschool system.
#

#
# If user is assigned to multiple schools no delete action is triggered.
# Remove from the right school is not handled by this hook by handled but
# by ucs by modifing the users school. So no testcases for this case are
# neccessary.
#


def test_deactivate_user_before_deletion__with_one_school(
	get_base, ldap_access_admin, student_obj, create_user, remove_user, get_missing_groups):
	"""
	This test case tests the pre_remove hook 'deactivate_user_before_deletion'
	if the user (e.g. student) is assigned to only one school. In this case,
	the student should be moved to the limbo school and no longer have a
	connection to the old school.
	"""
	#school = "DEMOSCHOOL"
	# @todo school_admin
	# => permissionDenied: Can not modify lock time of
	# 'cn=testuser,cn=uid,cn=temporary,cn=univention,dc=lernen,dc=hamburg'.
	# lo = ldap_access_school_admin
	lo = ldap_access_admin
	student = student_obj(school=school)
	student.school_classes[school] = ['5c']  # add school class to student

	# CREATE
	create_user(lo, student)
	udm_obj = student.get_udm_object(lo)
	assert udm_obj['username'] == student.name
	assert udm_obj['firstname'] == student.firstname
	assert udm_obj['lastname'] == student.lastname
	assert udm_obj.info['school'] == [school]
	assert len(get_missing_groups([
		'cn=Domain Users %s,cn=groups,ou=%s,%s' % (school, school, get_base),
		'cn=%s,cn=groups,ou=%s,%s' % (school_group, school, get_base),
		'cn=klassen,cn=schueler,cn=groups,ou=%s,%s' % (school, get_base)
	], udm_obj['groups'])) == 0

	# REMOVE
	remove_user(lo, student)
	udm_obj = student.get_udm_object(lo)  # get a fresh udm obj after deletion
	assert udm_obj['username'] == student.name
	assert udm_obj['firstname'] == student.firstname
	assert udm_obj['lastname'] == student.lastname
	assert udm_obj.info['school'] == ["DeaktivierteKonten"]
	assert udm_obj['disabled'] == "1"
	for group in udm_obj.info['groups']:
		assert group.endswith('ou=DeaktivierteKonten,%s' % get_base)


def test_deactivate_schooladmin_before_deletion__with_one_school(
	get_base, ldap_access_admin, schooladmin_obj, create_user, remove_user, get_missing_groups):
	"""
	This test case tests the pre_remove hook 'deactivate_user_before_deletion'
	if the  school_admin is assigned to only one school. In this case,
	the school_admin should be moved to the limbo school and no longer have a
	connection to the old school. Because of Bug 54368 it is also important to
	check for any leftover admins-<old school> groups.
	"""
	#school = "DEMOSCHOOL"
	lo = ldap_access_admin
	admin = schooladmin_obj(school=school)

	# CREATE
	create_user(lo, admin)
	udm_obj = admin.get_udm_object(lo)
	assert udm_obj['username'] == admin.name
	assert udm_obj['firstname'] == admin.firstname
	assert udm_obj['lastname'] == admin.lastname
	assert udm_obj.info['school'] == [school]
	assert len(get_missing_groups([
		'cn=Domain Users %s,cn=groups,ou=%s,%s' % (school, school, get_base),
		'cn=%s,cn=ouadmins,cn=groups,ou=%s,%s' % (school_group, school, get_base),
	], udm_obj['groups'])) == 1

	# REMOVE
	remove_user(lo, admin)
	udm_obj = admin.get_udm_object(lo)  # get a fresh udm obj after deletion
	assert udm_obj['username'] == admin.name
	assert udm_obj['firstname'] == admin.firstname
	assert udm_obj['lastname'] == admin.lastname
	assert udm_obj.info['school'] == ["DeaktivierteKonten"]
	assert udm_obj['disabled'] == "1"
	for group in udm_obj.info['groups']:
		assert ('admins-%s' % school) not in group
