import logging
from config import school

LOGGER = logging.getLogger(__name__)

#
# Attention: This testcases will create users on the target system.
# Run this tests on a testing ucsschool system.
#


def test__generate_student_email__with_changes(
        caplog, get_base, get_mail_domain, ldap_access_admin, student_obj, create_user, modify_user, write_factory_config_file):
    #school = "DEMOSCHOOL"
    lo = ldap_access_admin
    student = student_obj(school=school)
    student.school_classes[school] = ['5c']  # add school class to student
    student.email = student.firstname[:2] + '.' + student.lastname[:2] + "@" + get_mail_domain

    # CREATE
    create_user(lo, student)
    udm_obj = student.get_udm_object(lo)
    assert udm_obj['username'] == student.name
    assert udm_obj['firstname'] == student.firstname
    assert udm_obj['lastname'] == student.lastname

    with caplog.at_level(logging.INFO):
        # MODIFY
        student.firstname = 'x' + student.firstname
        student.lastname = 'y' + student.lastname
        modify_user(lo, student)
        udm_obj = student.get_udm_object(lo)
        assert udm_obj['mailPrimaryAddress'] == student.firstname + '.' + student.lastname + '@' + get_mail_domain
        log_msg = "User attributes (firstname, lastname) of user %r was changed." % student.name
        assert log_msg in caplog.text


def test__generate_student_email__no_changes(
        caplog, get_base, get_mail_domain, ldap_access_admin, student_obj, create_user, modify_user, write_factory_config_file):

    lo = ldap_access_admin
    student = student_obj(school=school)
    student.school_classes[school] = ['5c']  # add school class to student
    student.email = student.firstname[:2] + '.' + student.lastname[:2] + "@" + get_mail_domain

    # CREATE
    create_user(lo, student)
    udm_obj = student.get_udm_object(lo)
    assert udm_obj['username'] == student.name
    assert udm_obj['firstname'] == student.firstname
    assert udm_obj['lastname'] == student.lastname

    with caplog.at_level(logging.INFO):
        # MODIFY
        modify_user(lo, student)
        udm_obj = student.get_udm_object(lo)
        assert udm_obj['mailPrimaryAddress'] == student.email  # No email should changed
        log_msg = "No changes of user attributes (firstname, lastname) of user %r detected." % student.name
        assert log_msg in caplog.text


def test__generate_teacher_email__with_changes(
        caplog, get_base, get_mail_domain, ldap_access_admin, teacher_obj, create_user, modify_user, write_factory_config_file):

    lo = ldap_access_admin
    teacher = teacher_obj(school=school)
    teacher.school_classes[school] = ['5c']  # add school class to teacher
    teacher.email = teacher.firstname[:2] + '.' + teacher.lastname[:2] + "@" + get_mail_domain

    # CREATE
    create_user(lo, teacher)
    udm_obj = teacher.get_udm_object(lo)
    assert udm_obj['username'] == teacher.name
    assert udm_obj['firstname'] == teacher.firstname
    assert udm_obj['lastname'] == teacher.lastname

    with caplog.at_level(logging.INFO):
        # MODIFY
        teacher.firstname = 'x' + teacher.firstname
        teacher.lastname = 'y' + teacher.lastname
        modify_user(lo, teacher)
        udm_obj = teacher.get_udm_object(lo)
        assert udm_obj['mailPrimaryAddress'] == teacher.firstname + '.' + teacher.lastname + '@' + get_mail_domain
        log_msg = "User attributes (firstname, lastname) of user %r was changed." % teacher.name
        assert log_msg in caplog.text


def test__generate_teacher_email__no_changes(
        caplog, get_base, get_mail_domain, ldap_access_admin, teacher_obj, create_user, modify_user, write_factory_config_file):

    lo = ldap_access_admin
    teacher = teacher_obj(school=school)
    teacher.school_classes[school] = ['5c']  # add school class to teacher
    teacher.email = teacher.firstname[:2] + '.' + teacher.lastname[:2] + "@" + get_mail_domain

    # CREATE
    create_user(lo, teacher)
    udm_obj = teacher.get_udm_object(lo)
    assert udm_obj['username'] == teacher.name
    assert udm_obj['firstname'] == teacher.firstname
    assert udm_obj['lastname'] == teacher.lastname

    with caplog.at_level(logging.INFO):
        # MODIFY
        modify_user(lo, teacher)
        udm_obj = teacher.get_udm_object(lo)
        assert udm_obj['mailPrimaryAddress'] == teacher.email  # No email should changed
        log_msg = "No changes of user attributes (firstname, lastname) of user %r detected." % teacher.name
        assert log_msg in caplog.text


def test__generate_schooladmin_email__with_changes(
        caplog, get_base, get_mail_domain, ldap_access_admin, schooladmin_obj, create_user, modify_user, write_factory_config_file):

    lo = ldap_access_admin
    schooladmin = schooladmin_obj(school=school)
    schooladmin.school_classes[school] = ['5c']  # add school class to schooladmin
    schooladmin.email = schooladmin.firstname[:2] + '.' + schooladmin.lastname[:2] + "@" + get_mail_domain

    # CREATE
    create_user(lo, schooladmin)
    udm_obj = schooladmin.get_udm_object(lo)
    assert udm_obj['username'] == schooladmin.name
    assert udm_obj['firstname'] == schooladmin.firstname
    assert udm_obj['lastname'] == schooladmin.lastname

    with caplog.at_level(logging.INFO):
        # MODIFY
        schooladmin.firstname = 'x' + schooladmin.firstname
        schooladmin.lastname = 'y' + schooladmin.lastname
        modify_user(lo, schooladmin)
        udm_obj = schooladmin.get_udm_object(lo)
        #assert udm_obj['mailPrimaryAddress'] == schooladmin.firstname[1:3] + '.' + schooladmin.lastname[1:3] + '@' + get_mail_domain
        assert udm_obj['mailPrimaryAddress'] == schooladmin.firstname + '.' + schooladmin.lastname + '@' + get_mail_domain
        log_msg = "User attributes (firstname, lastname) of user %r was changed." % schooladmin.name
        assert log_msg in caplog.text


def test__generate_schooladmin_email__no_changes(
        caplog, get_base, get_mail_domain, ldap_access_admin, schooladmin_obj, create_user, modify_user, write_factory_config_file):

    lo = ldap_access_admin
    schooladmin = schooladmin_obj(school=school)
    schooladmin.school_classes[school] = ['5c']  # add school class to schooladmin
    schooladmin.email = schooladmin.firstname[:2] + '.' + schooladmin.lastname[:2] + "@" + get_mail_domain

    # CREATE
    create_user(lo, schooladmin)
    udm_obj = schooladmin.get_udm_object(lo)
    assert udm_obj['username'] == schooladmin.name
    assert udm_obj['firstname'] == schooladmin.firstname
    assert udm_obj['lastname'] == schooladmin.lastname

    with caplog.at_level(logging.INFO):
        # MODIFY
        modify_user(lo, schooladmin)
        udm_obj = schooladmin.get_udm_object(lo)
        assert udm_obj['mailPrimaryAddress'] == schooladmin.email  # No email should changed
        log_msg = "No changes of user attributes (firstname, lastname) of user %r detected." % schooladmin.name
        assert log_msg in caplog.text
