from datetime import datetime
from config import school
import logging

LOGGER = logging.getLogger(__name__)

#
# Attention: This testcases will create users on the target system.
# Run this tests on a testing ucsschool system.
#


def test__generate_mail_alias__with_changes(
		caplog, get_base, get_mail_domain, ldap_access_admin, student_obj, create_user, modify_user, write_factory_config_file):

	lo = ldap_access_admin
	student = student_obj(school=school)
	student.school_classes[school] = ['5c']  # add school class to student
	student.email = student.firstname + '.' + student.lastname + '@' + get_mail_domain

	# CREATE
	create_user(lo, student)
	udm_obj = student.get_udm_object(lo)
	assert udm_obj['username'] == student.name
	assert udm_obj['firstname'] == student.firstname
	assert udm_obj['lastname'] == student.lastname
	mail_primary = udm_obj['mailPrimaryAddress']

	with caplog.at_level(logging.INFO):
		# MODIFY
		student.firstname = 'x' + student.firstname
		student.lastname = 'y' + student.lastname
		modify_user(lo, student)
		udm_obj = student.get_udm_object(lo)
		assert len(udm_obj['mailAlternativeAddress']) == 1

		# mailPrimaryAddress ist ungleich mailAlternativeAddress 
		#assert udm_obj['mailPrimaryAddress'] in udm_obj['mailAlternativeAddress']
		# Ändern in
		assert mail_primary in udm_obj['mailAlternativeAddress']

		assert len(udm_obj['mailAddressExpired']) == 1

		#Diese assert kann unmöglich True zurückliefern denn von dem Zeitpunt obj['mailAddressExpired']
		# gesetzt wird bis zur Zeitpunkt sie es geprüft wird, vergehen immer einige Millisekunden und daher niemals gleich.
		#assert datetime.now().strftime("%Y-%m-%d %H:%M:%S") in udm_obj['mailAddressExpired']

		log_msg = "User attributes (firstname, lastname) of user %r was changed." % student.name
		assert log_msg in caplog.text


def test__generate_mail_alias__no_changes(
		caplog, get_base, get_mail_domain, ldap_access_admin, student_obj, create_user, modify_user, write_factory_config_file):
	lo = ldap_access_admin
	student = student_obj(school=school)
	student.school_classes[school] = ['5c']  # add school class to student
	student.email = student.firstname + '.' + student.lastname + '@' + get_mail_domain

	# CREATE
	create_user(lo, student)
	udm_obj = student.get_udm_object(lo)
	assert udm_obj['username'] == student.name
	assert udm_obj['firstname'] == student.firstname
	assert udm_obj['lastname'] == student.lastname

	with caplog.at_level(logging.INFO):
		# MODIFY
		modify_user(lo, student)
		udm_obj = student.get_udm_object(lo)
		assert len(udm_obj['mailAlternativeAddress']) == 0
		assert udm_obj['mailPrimaryAddress'] not in udm_obj['mailAlternativeAddress']
		assert len(udm_obj['mailAddressExpired']) == 0
		assert datetime.now().strftime("%Y-%m-%d %H:%M:%S") not in udm_obj['mailAddressExpired']
		log_msg = "No changes of user attributes (firstname, lastname) of user %r detected." % student.name
		assert log_msg in caplog.text
