import logging
from config import school
LOGGER = logging.getLogger(__name__)

#
# Attention: This testcases will create users on the target system.
# Run this tests on a testing ucsschool system.
#


def test__generate_student_username__with_changes(
		caplog, get_base, ldap_access_admin, student_obj, create_user, modify_user, write_factory_config_file):
	#school = "DEMOSCHOOL"
	lo = ldap_access_admin
	student = student_obj(school=school)
	student.school_classes[school] = ['5c']  # add school class to student

	# CREATE
	create_user(lo, student)
	udm_obj = student.get_udm_object(lo)
	assert udm_obj['username'] == student.name
	assert udm_obj['firstname'] == student.firstname
	assert udm_obj['lastname'] == student.lastname

	with caplog.at_level(logging.INFO):
		# MODIFY
		student.firstname = 'x' + student.firstname
		student.lastname = 'y' + student.lastname
		modify_user(lo, student)
		udm_obj = student.get_udm_object(lo)
		assert udm_obj['username'] == student.firstname[0] + student.lastname[:6]
		assert udm_obj['username'][0] == 'x'
		assert udm_obj['username'][1] == 'y'
		log_msg = "User attributes (firstname, lastname) of user %r was changed." % student.name
		assert log_msg in caplog.text


def test__generate_student_username__no_changes(
		caplog, get_base, ldap_access_admin, student_obj, create_user, modify_user, write_factory_config_file):
	#school = "DEMOSCHOOL"
	lo = ldap_access_admin
	student = student_obj(school=school)
	student.school_classes[school] = ['5c']  # add school class to student

	# CREATE
	create_user(lo, student)
	udm_obj = student.get_udm_object(lo)
	assert udm_obj['username'] == student.name
	assert udm_obj['firstname'] == student.firstname
	assert udm_obj['lastname'] == student.lastname

	with caplog.at_level(logging.INFO):
		# MODIFY
		modify_user(lo, student)
		udm_obj = student.get_udm_object(lo)
		udm_obj = student.get_udm_object(lo)
		assert udm_obj['username'] == student.name  # Name was not changed.
		log_msg = "No changes of user attributes (firstname, lastname) of user %r detected." % student.name
		assert log_msg in caplog.text

def test__teacher_username__with_changes(
		caplog, get_base, ldap_access_admin, teacher_obj, create_user, modify_user, write_factory_config_file):
	#school = "DEMOSCHOOL"
	lo = ldap_access_admin
	teacher = teacher_obj(school=school)
	teacher.school_classes[school] = ['5c']  # add school class to teacher

	# CREATE
	create_user(lo, teacher)
	udm_obj = teacher.get_udm_object(lo)
	assert udm_obj['username'] == teacher.name
	assert udm_obj['firstname'] == teacher.firstname
	assert udm_obj['lastname'] == teacher.lastname

	with caplog.at_level(logging.INFO):
		# MODIFY
		teacher.firstname = 'x' + teacher.firstname
		teacher.lastname = 'y' + teacher.lastname
		modify_user(lo, teacher)
		udm_obj = teacher.get_udm_object(lo)
		assert udm_obj['username'] == teacher.firstname[0] + teacher.lastname[:6]
		assert udm_obj['username'][0] == 'x'
		assert udm_obj['username'][1] == 'y'
		log_msg = "User attributes (firstname, lastname) of user %r was changed." % teacher.name
		assert log_msg in caplog.text


def test__generate_teacher_username__no_changes(
		caplog, get_base, ldap_access_admin, teacher_obj, create_user, modify_user, write_factory_config_file):
	#school = "DEMOSCHOOL"
	lo = ldap_access_admin
	teacher = teacher_obj(school=school)
	teacher.school_classes[school] = ['5c']  # add school class to teacher

	# CREATE
	create_user(lo, teacher)
	udm_obj = teacher.get_udm_object(lo)
	assert udm_obj['username'] == teacher.name
	assert udm_obj['firstname'] == teacher.firstname
	assert udm_obj['lastname'] == teacher.lastname

	with caplog.at_level(logging.INFO):
		# MODIFY
		modify_user(lo, teacher)
		udm_obj = teacher.get_udm_object(lo)
		udm_obj = teacher.get_udm_object(lo)
		assert udm_obj['username'] == teacher.name  # Name was not changed.
		log_msg = "No changes of user attributes (firstname, lastname) of user %r detected." % teacher.name
		assert log_msg in caplog.text

def test__schooladmin_username__with_changes(
		caplog, get_base, ldap_access_admin, schooladmin_obj, create_user, modify_user, write_factory_config_file):
	#school = "DEMOSCHOOL"
	lo = ldap_access_admin
	schooladmin = schooladmin_obj(school=school)
	schooladmin.school_classes[school] = ['5c']  # add school class to schooladmin

	# CREATE
	create_user(lo, schooladmin)
	udm_obj = schooladmin.get_udm_object(lo)
	assert udm_obj['username'] == schooladmin.name
	assert udm_obj['firstname'] == schooladmin.firstname
	assert udm_obj['lastname'] == schooladmin.lastname

	with caplog.at_level(logging.INFO):
		# MODIFY
		schooladmin.firstname = 'x' + schooladmin.firstname
		schooladmin.lastname = 'y' + schooladmin.lastname
		modify_user(lo, schooladmin)
		udm_obj = schooladmin.get_udm_object(lo)
		assert udm_obj['username'] == schooladmin.firstname[0] + schooladmin.lastname[:6]
		assert udm_obj['username'][0] == 'x'
		assert udm_obj['username'][1] == 'y'
		log_msg = "User attributes (firstname, lastname) of user %r was changed." % schooladmin.name
		assert log_msg in caplog.text


def test__generate_schooladmin_username__no_changes(
		caplog, get_base, ldap_access_admin, schooladmin_obj, create_user, modify_user, write_factory_config_file):
	#school = "DEMOSCHOOL"
	lo = ldap_access_admin
	schooladmin = schooladmin_obj(school=school)

	# CREATE
	create_user(lo, schooladmin)
	udm_obj = schooladmin.get_udm_object(lo)
	assert udm_obj['username'] == schooladmin.name
	assert udm_obj['firstname'] == schooladmin.firstname
	assert udm_obj['lastname'] == schooladmin.lastname

	with caplog.at_level(logging.INFO):
		# MODIFY
		modify_user(lo, schooladmin)
		udm_obj = schooladmin.get_udm_object(lo)
		udm_obj = schooladmin.get_udm_object(lo)
		assert udm_obj['username'] == schooladmin.name  # Name was not changed.
		log_msg = "No changes of user attributes (firstname, lastname) of user %r detected." % schooladmin.name
		assert log_msg in caplog.text
