import logging
import datetime
from config import school, school_group
logging.basicConfig(level=logging.DEBUG, format="%(message)s",
	handlers=[logging.StreamHandler()])

#
# Attention: This testcases will create users on the target system.
# Run this tests on a testing ucsschool system.
#


def test_purge_deactivated_users(
	get_base, ldap_access_admin, student_obj, create_user, modify_user, get_missing_groups):
	"""
	This test case tests the post_modify hook 'purge_deactivated_users'
	if the user (e.g. student) is deactivated, his ucsschoolPurgeTimestamp
	should be set to the value stored in the UCR variable
	'dataport/schuposh/ulc/purge_period'.
	"""
	#school = "DEMOSCHOOL"
	# @todo school_admin
	# => permissionDenied: Can not modify lock time of
	# 'cn=testuser,cn=uid,cn=temporary,cn=univention,dc=lernen,dc=hamburg'.
	# lo = ldap_access_school_admin
	lo = ldap_access_admin
	student = student_obj(school=school)
	student.school_classes[school] = ['5c']  # add school class to student

	# CREATE
	create_user(lo, student)
	udm_obj = student.get_udm_object(lo)
	assert udm_obj['username'] == student.name
	assert udm_obj['firstname'] == student.firstname
	assert udm_obj['lastname'] == student.lastname
	assert udm_obj.info['school'] == [school]
	assert "pupil" == student.roles[0]
	assert student.is_active() is True
	assert len(get_missing_groups([
		'cn=Domain Users %s,cn=groups,ou=%s,%s' % (school, school, get_base),
		'cn=%s,cn=groups,ou=%s,%s' % (school_group, school, get_base),
		'cn=klassen,cn=schueler,cn=groups,ou=%s,%s' % (school, get_base)
	], udm_obj['groups'])) == 0

	# DEACTIVATE
	student.disabled = True
	modify_user(lo, student)
	udm_obj = student.get_udm_object(lo)  # get a fresh udm obj after deletion
	# convert UTC time string to date format
	purgeDate = datetime.datetime.strptime(udm_obj["ucsschoolPurgeTimestamp"], "%Y-%m-%d")
	assert datetime.datetime.now() <= purgeDate

	# REACTIVATE
	student.disabled = False
	modify_user(lo, student)
	udm_obj = student.get_udm_object(lo)  # get a fresh udm obj after deletion
	assert student.is_active() is True
	# We don't check the ucsschoolPurgeTimestamp here, because it's still there
	# and gets removed by the next cronjob run
