import logging
import mock
from config import school
LOGGER = logging.getLogger(__name__)

#
# Attention: This testcases will create users on the target system.
# Run this tests on a testing ucsschool system.
#


def test_send_mail_on_user_changes__with_changes(
		caplog, get_base, ldap_access_admin, student_obj, create_user, modify_user):

	with caplog.at_level(logging.INFO):

		lo = ldap_access_admin
		student = student_obj(school=school)
		student.school_classes[school] = ['5c']  # add school class to student
		# CREATE
		create_user(lo, student)
		udm_obj = student.get_udm_object(lo)
		assert udm_obj['username'] == student.name
		assert udm_obj['firstname'] == student.firstname
		assert udm_obj['lastname'] == student.lastname
		# MODIFY
		# Mock mailer.Mailer.send to prevent sending mails in testcases.
		with mock.patch("mailer.Mailer.send", return_value=True):
			student.firstname = student.firstname + '_updated'
			student.lastname = student.lastname + '_updated'
			modify_user(lo, student)
			udm_obj = student.get_udm_object(lo)
			assert udm_obj['firstname'] == student.firstname
			assert udm_obj['lastname'] == student.lastname
			log_msg = "User attributes (firstname, lastname) of user %r was changed." % student.name
			assert log_msg in caplog.text
			#assert "OK: Sent email(s) to school(s)." in caplog.text


def test_send_mail_on_user_changes__no_changes(
		caplog, get_base, ldap_access_admin, student_obj, create_user, modify_user):
	with caplog.at_level(logging.INFO):

		lo = ldap_access_admin
		student = student_obj(school=school)
		student.school_classes[school] = ['5c']  # add school class to student
		# CREATE
		create_user(lo, student)
		udm_obj = student.get_udm_object(lo)
		assert udm_obj['username'] == student.name
		assert udm_obj['firstname'] == student.firstname
		assert udm_obj['lastname'] == student.lastname
		# MODIFY
		student.firstname = student.firstname
		student.lastname = student.lastname
		modify_user(lo, student)
		udm_obj = student.get_udm_object(lo)
		assert udm_obj['firstname'] == student.firstname
		assert udm_obj['lastname'] == student.lastname
		log_msg = "No changes of user attributes (firstname, lastname) of user %r detected." % student.name
		assert log_msg in caplog.text
